==> CryptoLib-1.1.0-sources.jar: com/miketheshadow/cryptolib/price/PriceLib.java <==
package com.miketheshadow.cryptolib.price;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.miketheshadow.cryptolib.CryptoLib;
import com.miketheshadow.cryptolib.request.PreBuiltRequests;
import com.miketheshadow.cryptolib.request.RequestException;
import com.miketheshadow.cryptolib.utils.TextFormatter;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class PriceLib {

    boolean isDex = false;
    String dexToken;
    String dexUrl;
    CryptoLib lib;
    String exchange;
    String pairAddress;
    double cachedPrice;

    public PriceLib(CryptoLib lib, String exchange,String pairAddress) {
        this.lib = lib;
        this.exchange = exchange;
        this.pairAddress = pairAddress;
    }

    public PriceLib(String dexUrl, String dexToken) {
        isDex = true;
        this.dexUrl = dexUrl;
        this.dexToken = dexToken;
    }

    public double getNewPrice() throws RequestException {

        double price;

        if(isDex) {
            try {
                OkHttpClient client = new OkHttpClient().newBuilder()
                        .build();
                Request request = new Request.Builder()
                        .url("https://api.dexscreener.com/latest/dex/pairs/osmosis/2")
                        .get()
                        .build();
                Response response = client.newCall(request).execute();
                ObjectMapper mapper = new ObjectMapper();
                DexToolsPriceData data = mapper.readValue(response.body().string(),DexToolsPriceData.class);
                price =  data.pair.priceUsd;
            } catch (Exception e) {
                throw new RequestException("Error occurred while fetching price: " + e.getMessage());
            }
        } else {
            double exchangeFirstBalance = lib.walletUtils.getBalance(exchange);
            int zeros = lib.contractUtils.getZerosForOtherToken(pairAddress);
            double exchangeSecondBalance = lib.walletUtils.getOtherTokenBalance(pairAddress,exchange,zeros);
            price =  exchangeSecondBalance / exchangeFirstBalance;
        }
        cachedPrice = price;
        return price;
    }

    public double getCachedPrice() {
        return cachedPrice;
    }

    public String getNewPriceFormatted() throws RequestException {
        return TextFormatter.formatPriceExperimental(this.getNewPrice());
    }

    public String getCachedPriceFormatted() {
        return TextFormatter.formatPriceExperimental(this.cachedPrice);
    }
}

==> CryptoLib-1.1.1-sources.jar: com/miketheshadow/cryptolib/price/PriceLib.java <==
package com.miketheshadow.cryptolib.price;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.miketheshadow.cryptolib.CryptoLib;
import com.miketheshadow.cryptolib.request.PreBuiltRequests;
import com.miketheshadow.cryptolib.request.RequestException;
import com.miketheshadow.cryptolib.utils.TextFormatter;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class PriceLib {

    boolean isDex = false;
    String dexToken;
    String dexUrl;
    CryptoLib lib;
    String exchange;
    String pairAddress;
    double cachedPrice;
    int pairZeros = 0;

    public PriceLib(CryptoLib lib, String exchange,String pairAddress) {
        this.lib = lib;
        this.exchange = exchange;
        this.pairAddress = pairAddress;
    }

    public PriceLib(String dexUrl, String dexToken) {
        isDex = true;
        this.dexUrl = dexUrl;
        this.dexToken = dexToken;
    }

    public double getNewPrice() throws RequestException {

        double price;

        if(isDex) {
            try {
                OkHttpClient client = new OkHttpClient().newBuilder()
                        .build();
                Request request = new Request.Builder()
                        .url("https://api.dexscreener.com/latest/dex/pairs/osmosis/2")
                        .get()
                        .build();
                Response response = client.newCall(request).execute();
                ObjectMapper mapper = new ObjectMapper();
                DexToolsPriceData data = mapper.readValue(response.body().string(),DexToolsPriceData.class);
                price =  data.pair.priceUsd;
            } catch (Exception e) {
                throw new RequestException("Error occurred while fetching price: " + e.getMessage());
            }
        } else {
            double exchangeFirstBalance = lib.walletUtils.getBalance(exchange);
            if(this.pairZeros == 0){
                pairZeros = lib.contractUtils.getZerosForOtherToken(pairAddress);
            }

            double exchangeSecondBalance = lib.walletUtils.getOtherTokenBalance(pairAddress,exchange,pairZeros);
            price =  exchangeSecondBalance / exchangeFirstBalance;
        }
        cachedPrice = price;
        return price;
    }

    public double getCachedPrice() {
        return cachedPrice;
    }

    public String getNewPriceFormatted() throws RequestException {
        return TextFormatter.formatPriceExperimental(this.getNewPrice());
    }

    public String getCachedPriceFormatted() {
        return TextFormatter.formatPriceExperimental(this.cachedPrice);
    }
}
